import os
import telebot


class TgLogsMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response
        self.bot = telebot.TeleBot(os.getenv('tg_api_key'))


    def __call__(self, request):

        response = self.get_response(request)
        if 400 >= response.status <= 500:
            self.bot.send_message(
                chat_id=os.getenv('chat_id'),
                text=f'Status code: {response.status}\nBody: {response.body}',
                disable_web_page_preview=True
            )

        return response


from setuptools import setup, find_packages

with open("README.md", "r") as readme_file:
    readme = readme_file.read()

requirements = ["django>=3.0", "pyTelegramBotAPI>=4.4.0"]

setup(
    name="django-tg-logs",
    version="0.0.1",
    author="Inkviz96",
    author_email="b-semen-b@mail.ru",
    description="A package to convert your Jupyter Notebook",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/inkviz96/django-tg-logs",
    packages=find_packages(),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)